/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __TEST_AUTOLOAD_SKEL_H__
#define __TEST_AUTOLOAD_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct test_autoload {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *bss;
	} maps;
	struct {
		struct bpf_program *prog1;
		struct bpf_program *prog2;
		struct bpf_program *prog3;
	} progs;
	struct {
		struct bpf_link *prog1;
		struct bpf_link *prog2;
		struct bpf_link *prog3;
	} links;
	struct test_autoload__bss {
		bool prog1_called;
		bool prog2_called;
		bool prog3_called;
	} *bss;
};

static void
test_autoload__destroy(struct test_autoload *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
test_autoload__create_skeleton(struct test_autoload *obj);

static inline struct test_autoload *
test_autoload__open_opts(const struct bpf_object_open_opts *opts)
{
	struct test_autoload *obj;
	int err;

	obj = (struct test_autoload *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = test_autoload__create_skeleton(obj);
	err = err ?: bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	test_autoload__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct test_autoload *
test_autoload__open(void)
{
	return test_autoload__open_opts(NULL);
}

static inline int
test_autoload__load(struct test_autoload *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct test_autoload *
test_autoload__open_and_load(void)
{
	struct test_autoload *obj;
	int err;

	obj = test_autoload__open();
	if (!obj)
		return NULL;
	err = test_autoload__load(obj);
	if (err) {
		test_autoload__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
test_autoload__attach(struct test_autoload *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
test_autoload__detach(struct test_autoload *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline int
test_autoload__create_skeleton(struct test_autoload *obj)
{
	struct bpf_object_skeleton *s;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)
		goto err;
	obj->skeleton = s;

	s->sz = sizeof(*s);
	s->name = "test_autoload";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 1;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps)
		goto err;

	s->maps[0].name = "test_aut.bss";
	s->maps[0].map = &obj->maps.bss;
	s->maps[0].mmaped = (void **)&obj->bss;

	/* programs */
	s->prog_cnt = 3;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs)
		goto err;

	s->progs[0].name = "prog1";
	s->progs[0].prog = &obj->progs.prog1;
	s->progs[0].link = &obj->links.prog1;

	s->progs[1].name = "prog2";
	s->progs[1].prog = &obj->progs.prog2;
	s->progs[1].link = &obj->links.prog2;

	s->progs[2].name = "prog3";
	s->progs[2].prog = &obj->progs.prog3;
	s->progs[2].link = &obj->links.prog3;

	s->data_sz = 2832;
	s->data = (void *)"\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xd0\x07\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0d\0\
\x01\0\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x72\x61\
\x77\x5f\x74\x70\x2f\x73\x79\x73\x5f\x65\x6e\x74\x65\x72\0\x72\x61\x77\x5f\x74\
\x70\x2f\x73\x79\x73\x5f\x65\x78\x69\x74\0\x66\x65\x6e\x74\x72\x79\x2f\x75\x6e\
\x65\x78\x69\x73\x74\x69\x6e\x67\x2d\x6b\x70\x72\x6f\x62\x65\x2d\x77\x69\x6c\
\x6c\x2d\x66\x61\x69\x6c\x2d\x69\x66\x2d\x6c\x6f\x61\x64\x65\x64\0\x2e\x62\x73\
\x73\0\x6c\x69\x63\x65\x6e\x73\x65\0\x74\x65\x73\x74\x5f\x61\x75\x74\x6f\x6c\
\x6f\x61\x64\x2e\x63\0\x70\x72\x6f\x67\x31\0\x70\x72\x6f\x67\x31\x5f\x63\x61\
\x6c\x6c\x65\x64\0\x70\x72\x6f\x67\x32\0\x70\x72\x6f\x67\x32\x5f\x63\x61\x6c\
\x6c\x65\x64\0\x70\x72\x6f\x67\x33\0\x70\x72\x6f\x67\x33\x5f\x63\x61\x6c\x6c\
\x65\x64\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x65\x6c\x72\x61\x77\x5f\
\x74\x70\x2f\x73\x79\x73\x5f\x65\x6e\x74\x65\x72\0\x2e\x72\x65\x6c\x72\x61\x77\
\x5f\x74\x70\x2f\x73\x79\x73\x5f\x65\x78\x69\x74\0\x2e\x72\x65\x6c\x66\x65\x6e\
\x74\x72\x79\x2f\x75\x6e\x65\x78\x69\x73\x74\x69\x6e\x67\x2d\x6b\x70\x72\x6f\
\x62\x65\x2d\x77\x69\x6c\x6c\x2d\x66\x61\x69\x6c\x2d\x69\x66\x2d\x6c\x6f\x61\
\x64\x65\x64\0\x2e\x42\x54\x46\0\x2e\x42\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x6c\0\0\0\x04\0\xf1\xff\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x03\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x05\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x7c\0\0\0\x12\0\x03\0\0\0\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\x82\
\0\0\0\x11\0\x06\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x8f\0\0\0\x12\0\x04\0\0\0\
\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\x95\0\0\0\x11\0\x06\0\x01\0\0\0\0\0\0\0\x01\0\0\
\0\0\0\0\0\xa2\0\0\0\x12\0\x05\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\xa8\0\0\0\
\x11\0\x06\0\x02\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\xb5\0\0\0\x11\0\x07\0\0\0\0\0\
\0\0\0\0\x04\0\0\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x02\0\0\x01\
\0\0\0\x73\x21\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x18\x01\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\xb7\x02\0\0\x01\0\0\0\x73\x21\0\0\0\0\0\0\xb7\0\0\0\0\0\0\
\0\x95\0\0\0\0\0\0\0\xb7\x02\0\0\x7b\0\0\0\x63\x21\0\0\0\0\0\0\x18\x01\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\xb7\x02\0\0\x01\0\0\0\x73\x21\0\0\0\0\0\0\xb7\0\0\0\0\0\0\
\0\x95\0\0\0\0\0\0\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x06\0\0\0\
\0\0\0\0\0\0\0\0\x01\0\0\0\x08\0\0\0\x10\0\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\x9f\
\xeb\x01\0\x18\0\0\0\0\0\0\0\x54\x01\0\0\x54\x01\0\0\xef\x01\0\0\0\0\0\0\0\0\0\
\x02\x02\0\0\0\0\0\0\0\0\0\0\x0a\0\0\0\0\0\0\0\0\x01\0\0\x0d\x04\0\0\0\x01\0\0\
\0\x01\0\0\0\x05\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\x01\x09\0\0\0\x01\0\0\x0c\
\x03\0\0\0\x0f\0\0\0\x01\0\0\x0c\x03\0\0\0\x15\0\0\0\x01\0\0\x0c\x03\0\0\0\x1b\
\0\0\0\x01\0\0\x04\x04\0\0\0\x2e\0\0\0\x04\0\0\0\0\0\0\0\x37\0\0\0\0\0\0\x08\
\x0a\0\0\0\x3c\0\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\x04\x42\0\0\0\0\0\0\x0e\x09\0\
\0\0\x01\0\0\0\x4f\0\0\0\0\0\0\x0e\x09\0\0\0\x01\0\0\0\x5c\0\0\0\0\0\0\x0e\x09\
\0\0\0\x01\0\0\0\x69\0\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\x01\0\0\0\0\0\0\0\x03\0\
\0\0\0\x0e\0\0\0\x10\0\0\0\x04\0\0\0\x6e\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\
\x82\0\0\0\0\0\0\x0e\x0f\0\0\0\x01\0\0\0\x94\x01\0\0\x03\0\0\x0f\x03\0\0\0\x0b\
\0\0\0\0\0\0\0\x01\0\0\0\x0c\0\0\0\x01\0\0\0\x01\0\0\0\x0d\0\0\0\x02\0\0\0\x01\
\0\0\0\x99\x01\0\0\x01\0\0\x0f\x04\0\0\0\x11\0\0\0\0\0\0\0\x04\0\0\0\0\x63\x74\
\x78\0\x69\x6e\x74\0\x70\x72\x6f\x67\x31\0\x70\x72\x6f\x67\x32\0\x70\x72\x6f\
\x67\x33\0\x66\x61\x6b\x65\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x73\x74\x72\x75\x63\
\x74\0\x77\x68\x61\x74\x65\x76\x65\x72\0\x62\x6f\x6f\x6c\0\x5f\x42\x6f\x6f\x6c\
\0\x70\x72\x6f\x67\x31\x5f\x63\x61\x6c\x6c\x65\x64\0\x70\x72\x6f\x67\x32\x5f\
\x63\x61\x6c\x6c\x65\x64\0\x70\x72\x6f\x67\x33\x5f\x63\x61\x6c\x6c\x65\x64\0\
\x63\x68\x61\x72\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\
\x50\x45\x5f\x5f\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2f\x62\x75\x69\x6c\x64\
\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\
\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x37\x30\x2e\x32\x32\x2e\x31\x2e\
\x65\x6c\x39\x5f\x30\x2f\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\x34\x2e\x30\x2d\
\x37\x30\x2e\x32\x32\x2e\x31\x2e\x65\x6c\x39\x5f\x30\x2e\x78\x38\x36\x5f\x36\
\x34\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\
\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x74\x65\
\x73\x74\x5f\x61\x75\x74\x6f\x6c\x6f\x61\x64\x2e\x63\0\x09\x70\x72\x6f\x67\x31\
\x5f\x63\x61\x6c\x6c\x65\x64\x20\x3d\x20\x74\x72\x75\x65\x3b\0\x09\x72\x65\x74\
\x75\x72\x6e\x20\x30\x3b\0\x09\x70\x72\x6f\x67\x32\x5f\x63\x61\x6c\x6c\x65\x64\
\x20\x3d\x20\x74\x72\x75\x65\x3b\0\x69\x6e\x74\x20\x70\x72\x6f\x67\x33\x28\x63\
\x6f\x6e\x73\x74\x20\x76\x6f\x69\x64\x20\x2a\x63\x74\x78\x29\0\x09\x66\x61\x6b\
\x65\x2d\x3e\x77\x68\x61\x74\x65\x76\x65\x72\x20\x3d\x20\x31\x32\x33\x3b\0\x09\
\x70\x72\x6f\x67\x33\x5f\x63\x61\x6c\x6c\x65\x64\x20\x3d\x20\x74\x72\x75\x65\
\x3b\0\x30\x3a\x30\0\x2e\x62\x73\x73\0\x6c\x69\x63\x65\x6e\x73\x65\0\x72\x61\
\x77\x5f\x74\x70\x2f\x73\x79\x73\x5f\x65\x6e\x74\x65\x72\0\x72\x61\x77\x5f\x74\
\x70\x2f\x73\x79\x73\x5f\x65\x78\x69\x74\0\x66\x65\x6e\x74\x72\x79\x2f\x75\x6e\
\x65\x78\x69\x73\x74\x69\x6e\x67\x2d\x6b\x70\x72\x6f\x62\x65\x2d\x77\x69\x6c\
\x6c\x2d\x66\x61\x69\x6c\x2d\x69\x66\x2d\x6c\x6f\x61\x64\x65\x64\0\0\0\0\0\0\
\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x34\0\0\0\x34\0\0\0\x9c\0\0\0\xd0\0\0\0\x1c\0\
\0\0\x08\0\0\0\xa1\x01\0\0\x01\0\0\0\0\0\0\0\x05\0\0\0\xb2\x01\0\0\x01\0\0\0\0\
\0\0\0\x06\0\0\0\xc2\x01\0\0\x01\0\0\0\0\0\0\0\x07\0\0\0\x10\0\0\0\xa1\x01\0\0\
\x02\0\0\0\0\0\0\0\x8b\0\0\0\x11\x01\0\0\x0f\x40\0\0\x20\0\0\0\x8b\0\0\0\x27\
\x01\0\0\x02\x44\0\0\xb2\x01\0\0\x02\0\0\0\0\0\0\0\x8b\0\0\0\x32\x01\0\0\x0f\
\x5c\0\0\x20\0\0\0\x8b\0\0\0\x27\x01\0\0\x02\x60\0\0\xc2\x01\0\0\x04\0\0\0\0\0\
\0\0\x8b\0\0\0\x48\x01\0\0\0\x80\0\0\x08\0\0\0\x8b\0\0\0\x63\x01\0\0\x11\x8c\0\
\0\x10\0\0\0\x8b\0\0\0\x7a\x01\0\0\x0f\x90\0\0\x30\0\0\0\x8b\0\0\0\x27\x01\0\0\
\x02\x94\0\0\x10\0\0\0\xc2\x01\0\0\x01\0\0\0\x08\0\0\0\x08\0\0\0\x90\x01\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\
\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x26\x01\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x68\x01\0\0\0\0\0\0\x20\x01\0\0\0\0\0\0\x01\0\0\0\0\0\
\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x11\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x88\x02\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x22\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\xb8\x02\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x32\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe8\x02\0\0\
\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x5f\0\0\0\x08\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x28\x03\0\0\0\0\0\0\x03\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x64\0\0\0\x01\
\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x28\x03\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xbe\0\0\0\x09\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x30\x03\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x02\0\0\0\x03\0\
\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xd3\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x40\x03\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x08\0\
\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xe7\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x50\x03\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x02\0\0\0\x05\0\0\0\x08\0\0\0\0\0\0\
\0\x10\0\0\0\0\0\0\0\x18\x01\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x60\
\x03\0\0\0\0\0\0\x5b\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x1d\x01\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc0\x06\0\0\0\0\
\0\0\x0c\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0";

	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return -ENOMEM;
}

#endif /* __TEST_AUTOLOAD_SKEL_H__ */
